@@ -29,9 +29,15 @@ from .models import Factors, Insights, Score
 from .validation import validate_report, validate_transaction
 
 
-_AIOHTTP_UA = "minFraud-API/%s %s" % (__version__, aiohttp.http.SERVER_SOFTWARE,)
+_AIOHTTP_UA = "minFraud-API/%s %s" % (
+    __version__,
+    aiohttp.http.SERVER_SOFTWARE,
+)
 
-_REQUEST_UA = "minFraud-API/%s %s" % (__version__, requests.utils.default_user_agent(),)
+_REQUEST_UA = "minFraud-API/%s %s" % (
+    __version__,
+    requests.utils.default_user_agent(),
+)
 
 
 # pylint: disable=too-many-instance-attributes, missing-class-docstring
@@ -71,7 +77,7 @@ class BaseClient:
             try:
                 validate_report(cleaned_request)
             except MultipleInvalid as ex:
-                raise InvalidRequestError("Invalid report data: {0}".format(ex))
+                raise InvalidRequestError("Invalid report data: {0}".format(ex)) from ex
         return cleaned_request
 
     def _prepare_transaction(self, request: Dict[str, Any], validate: bool):
@@ -80,7 +86,9 @@ class BaseClient:
             try:
                 validate_transaction(cleaned_request)
             except MultipleInvalid as ex:
-                raise InvalidRequestError("Invalid transaction data: {0}".format(ex))
+                raise InvalidRequestError(
+                    "Invalid transaction data: {0}".format(ex)
+                ) from ex
         return cleaned_request
 
     def _copy_and_clean(self, data: Any) -> Any:
@@ -102,14 +110,14 @@ class BaseClient:
         """Handle successful response."""
         try:
             decoded_body = json.loads(body)
-        except ValueError:
+        except ValueError as ex:
             raise MinFraudError(
                 "Received a 200 response"
                 " but could not decode the response as "
                 "JSON: {0}".format(body),
                 200,
                 uri,
-            )
+            ) from ex
         if "ip_address" in body:
             decoded_body["ip_address"]["_locales"] = self._locales
         return model_class(decoded_body)  # type: ignore
@@ -128,8 +136,8 @@ class BaseClient:
         if 400 <= status < 500:
             return self._exception_for_4xx_status(status, content_type, body, uri)
         if 500 <= status < 600:
-            return self._exception_for_5xx_status(status, uri)
-        return self._exception_for_unexpected_status(status, uri)
+            return self._exception_for_5xx_status(status, body, uri)
+        return self._exception_for_unexpected_status(status, body, uri)
 
     def _exception_for_4xx_status(
         self, status: int, content_type: str, body: str, uri: str
@@ -143,13 +151,14 @@ class BaseClient:
         """Returns exception for error responses with 4xx status codes."""
         if not body:
             return HTTPError(
-                "Received a {0} error with no body".format(status), status, uri
+                "Received a {0} error with no body".format(status), status, uri, body
             )
         if content_type.find("json") == -1:
             return HTTPError(
                 "Received a {0} with the following " "body: {1}".format(status, body),
                 status,
                 uri,
+                body,
             )
         try:
             decoded_body = json.loads(body)
@@ -161,6 +170,7 @@ class BaseClient:
                 ),
                 status,
                 uri,
+                body,
             )
         else:
             if "code" in decoded_body and "error" in decoded_body:
@@ -172,6 +182,7 @@ class BaseClient:
                 " or error keys: {0}".format(body),
                 status,
                 uri,
+                body,
             )
 
     @staticmethod
@@ -199,21 +210,31 @@ class BaseClient:
         return InvalidRequestError(message, code, status, uri)
 
     @staticmethod
-    def _exception_for_5xx_status(status: int, uri: str) -> HTTPError:
+    def _exception_for_5xx_status(
+        status: int,
+        body: Optional[str],
+        uri: str,
+    ) -> HTTPError:
         """Returns exception for error response with 5xx status codes."""
         return HTTPError(
             u"Received a server error ({0}) for " u"{1}".format(status, uri),
             status,
             uri,
+            body,
         )
 
     @staticmethod
-    def _exception_for_unexpected_status(status: int, uri: str) -> HTTPError:
+    def _exception_for_unexpected_status(
+        status: int,
+        body: Optional[str],
+        uri: str,
+    ) -> HTTPError:
         """Returns exception for responses with unexpected status codes."""
         return HTTPError(
             u"Received an unexpected HTTP status " u"({0}) for {1}".format(status, uri),
             status,
             uri,
+            body,
         )
 
 
