@@ -195,14 +195,21 @@ class BaseTransactionTest(BaseTest):
         self.assertEqual(self.cls(response), model)
         if self.has_ip_location():
             self.assertEqual("United Kingdom", model.ip_address.country.name)
+            self.assertEqual(True, model.ip_address.traits.is_residential_proxy)
 
     @httprettified
     def test_200_on_request_with_nones(self):
         model = self.create_success(
             request={
-                "device": {"ip_address": "81.2.69.160", "accept_language": None},
+                "device": {"ip_address": "152.216.7.110", "accept_language": None},
                 "event": {"shop_id": None},
-                "shopping_cart": [{"category": None, "quantity": 2,}, None],
+                "shopping_cart": [
+                    {
+                        "category": None,
+                        "quantity": 2,
+                    },
+                    None,
+                ],
             }
         )
         response = self.response
